@@ -7,14 +7,16 @@ from investing_algorithm_framework.core.events.observer import Observer
 
 class Worker(Observable, ABC):
     """
-    Class Worker: manages the execution of a task and the context around executing it.
+    Class Worker: manages the execution of a task and the context around
+    executing it.
     """
 
     id = None
 
     def start(self, **kwargs: Dict[str, Any]) -> None:
         """
-        Function that will start the worker, and notify its observers when it is finished
+        Function that will start the worker, and notify its observers when
+        it is finished
         """
 
         self.work(**kwargs)
@@ -40,4 +42,3 @@ class Worker(Observable, ABC):
         )
 
         return getattr(self, 'id')
-
